# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_schemeshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_schemeshard.proto\x12\x14NKikimr.NSchemeShard\x1a\x1eydb/core/protos/counters.proto*\x80O\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00\x12:\n\x1a\x43OUNTER_RESPONSE_TIME_USEC\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14ResponseTimeMicrosec\x12(\n\x11\x43OUNTER_DIR_COUNT\x10\x02\x1a\x11\x82\xd6\x1b\r\n\x0b\x44irectories\x12%\n\x13\x43OUNTER_TABLE_COUNT\x10\x03\x1a\x0c\x82\xd6\x1b\x08\n\x06Tables\x12*\n\x16\x43OUNTER_PQ_GROUP_COUNT\x10\x04\x1a\x0e\x82\xd6\x1b\n\n\x08PqGroups\x12=\n COUNTER_TABLE_SHARD_ACTIVE_COUNT\x10\x05\x1a\x17\x82\xd6\x1b\x13\n\x11TableShardsActive\x12\x41\n\"COUNTER_TABLE_SHARD_INACTIVE_COUNT\x10\x06\x1a\x19\x82\xd6\x1b\x15\n\x13TableShardsInactive\x12/\n\x16\x43OUNTER_PQ_SHARD_COUNT\x10\x07\x1a\x13\x82\xd6\x1b\x0f\n\rPqGroupShards\x12\x39\n\x19\x43OUNTER_PQ_RB_SHARD_COUNT\x10\x08\x1a\x1a\x82\xd6\x1b\x16\n\x14PqReadBalancerShards\x12.\n\x18\x43OUNTER_SUB_DOMAIN_COUNT\x10\t\x1a\x10\x82\xd6\x1b\x0c\n\nSubDomains\x12\x46\n$COUNTER_SUB_DOMAIN_COORDINATOR_COUNT\x10\n\x1a\x1c\x82\xd6\x1b\x18\n\x16SubDomainsCoordinators\x12@\n!COUNTER_SUB_DOMAIN_MEDIATOR_COUNT\x10\x0b\x1a\x19\x82\xd6\x1b\x15\n\x13SubDomainsMediators\x12\x35\n\x19\x43OUNTER_RTMR_VOLUME_COUNT\x10\x0c\x1a\x16\x82\xd6\x1b\x12\n\x10RtmrVolumesCount\x12<\n\x1d\x43OUNTER_RTMR_PARTITIONS_COUNT\x10\r\x1a\x19\x82\xd6\x1b\x15\n\x13RtmrPartitionsCount\x12<\n\x1f\x43OUNTER_BLOCKSTORE_VOLUME_COUNT\x10\x0e\x1a\x17\x82\xd6\x1b\x13\n\x11\x42lockStoreVolumes\x12G\n%COUNTER_BLOCKSTORE_VOLUME_SHARD_COUNT\x10\x0f\x1a\x1c\x82\xd6\x1b\x18\n\x16\x42lockStoreVolumeShards\x12M\n(COUNTER_BLOCKSTORE_PARTITION_SHARD_COUNT\x10\x10\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x42lockStorePartitionShards\x12>\n\x1f\x43OUNTER_IN_FLIGHT_OPS_TxInvalid\x10\x11\x1a\x19\x82\xd6\x1b\x15\n\x13InFlightOps/Invalid\x12:\n\x1d\x43OUNTER_IN_FLIGHT_OPS_TxMkDir\x10\x12\x1a\x17\x82\xd6\x1b\x13\n\x11InFlightOps/MkDir\x12\x46\n#COUNTER_IN_FLIGHT_OPS_TxCreateTable\x10\x13\x1a\x1d\x82\xd6\x1b\x19\n\x17InFlightOps/CreateTable\x12J\n%COUNTER_IN_FLIGHT_OPS_TxCreatePQGroup\x10\x14\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/CreatePQGroup\x12H\n$COUNTER_IN_FLIGHT_OPS_TxAlterPQGroup\x10\x15\x1a\x1e\x82\xd6\x1b\x1a\n\x18InFlightOps/AlterPQGroup\x12\x44\n\"COUNTER_IN_FLIGHT_OPS_TxAlterTable\x10\x16\x1a\x1c\x82\xd6\x1b\x18\n\x16InFlightOps/AlterTable\x12\x42\n!COUNTER_IN_FLIGHT_OPS_TxDropTable\x10\x17\x1a\x1b\x82\xd6\x1b\x17\n\x15InFlightOps/DropTable\x12\x46\n#COUNTER_IN_FLIGHT_OPS_TxDropPQGroup\x10\x18\x1a\x1d\x82\xd6\x1b\x19\n\x17InFlightOps/DropPQGroup\x12\x42\n!COUNTER_IN_FLIGHT_OPS_TxModifyACL\x10\x19\x1a\x1b\x82\xd6\x1b\x17\n\x15InFlightOps/ModifyACL\x12:\n\x1d\x43OUNTER_IN_FLIGHT_OPS_TxRmDir\x10\x1a\x1a\x17\x82\xd6\x1b\x13\n\x11InFlightOps/RmDir\x12\x42\n!COUNTER_IN_FLIGHT_OPS_TxCopyTable\x10\x1b\x1a\x1b\x82\xd6\x1b\x17\n\x15InFlightOps/CopyTable\x12V\n+COUNTER_IN_FLIGHT_OPS_TxSplitTablePartition\x10\x1c\x1a%\x82\xd6\x1b!\n\x1fInFlightOps/SplitTablePartition\x12<\n\x1e\x43OUNTER_IN_FLIGHT_OPS_TxBackup\x10\x1d\x1a\x18\x82\xd6\x1b\x14\n\x12InFlightOps/Backup\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxCreateSubDomain\x10\x1e\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/CreateSubDomain\x12J\n%COUNTER_IN_FLIGHT_OPS_TxDropSubDomain\x10\x1f\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/DropSubDomain\x12P\n(COUNTER_IN_FLIGHT_OPS_TxCreateRtmrVolume\x10 \x1a\"\x82\xd6\x1b\x1e\n\x1cInFlightOps/CreateRtmrVolume\x12\\\n.COUNTER_IN_FLIGHT_OPS_TxCreateBlockStoreVolume\x10!\x1a(\x82\xd6\x1b$\n\"InFlightOps/CreateBlockStoreVolume\x12Z\n-COUNTER_IN_FLIGHT_OPS_TxAlterBlockStoreVolume\x10\"\x1a\'\x82\xd6\x1b#\n!InFlightOps/AlterBlockStoreVolume\x12\\\n.COUNTER_IN_FLIGHT_OPS_TxAssignBlockStoreVolume\x10#\x1a(\x82\xd6\x1b$\n\"InFlightOps/AssignBlockStoreVolume\x12X\n,COUNTER_IN_FLIGHT_OPS_TxDropBlockStoreVolume\x10$\x1a&\x82\xd6\x1b\"\n InFlightOps/DropBlockStoreVolume\x12<\n\x1d\x43OUNTER_IN_FLIGHT_OPS_UNKNOWN\x10%\x1a\x19\x82\xd6\x1b\x15\n\x13InFlightOps/UNKNOWN\x12$\n\x13\x43OUNTER_KESUS_COUNT\x10&\x1a\x0b\x82\xd6\x1b\x07\n\x05Kesus\x12\x30\n\x19\x43OUNTER_KESUS_SHARD_COUNT\x10\'\x1a\x11\x82\xd6\x1b\r\n\x0bKesusShards\x12\x46\n#COUNTER_IN_FLIGHT_OPS_TxCreateKesus\x10(\x1a\x1d\x82\xd6\x1b\x19\n\x17InFlightOps/CreateKesus\x12\x42\n!COUNTER_IN_FLIGHT_OPS_TxDropKesus\x10)\x1a\x1b\x82\xd6\x1b\x17\n\x15InFlightOps/DropKesus\x12T\n*COUNTER_IN_FLIGHT_OPS_TxForceDropSubDomain\x10*\x1a$\x82\xd6\x1b \n\x1eInFlightOps/ForceDropSubDomain\x12V\n+COUNTER_IN_FLIGHT_OPS_TxCreateSolomonVolume\x10+\x1a%\x82\xd6\x1b!\n\x1fInFlightOps/CreateSolomonVolume\x12R\n)COUNTER_IN_FLIGHT_OPS_TxDropSolomonVolume\x10,\x1a#\x82\xd6\x1b\x1f\n\x1dInFlightOps/DropSolomonVolume\x12;\n\x1c\x43OUNTER_SOLOMON_VOLUME_COUNT\x10-\x1a\x19\x82\xd6\x1b\x15\n\x13SolomonVolumesCount\x12\x42\n COUNTER_SOLOMON_PARTITIONS_COUNT\x10.\x1a\x1c\x82\xd6\x1b\x18\n\x16SolomonPartitionsCount\x12\x44\n\"COUNTER_IN_FLIGHT_OPS_TxAlterKesus\x10/\x1a\x1c\x82\xd6\x1b\x18\n\x16InFlightOps/AlterKesus\x12L\n&COUNTER_IN_FLIGHT_OPS_TxAlterSubDomain\x10\x30\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/AlterSubDomain\x12V\n+COUNTER_IN_FLIGHT_OPS_TxAlterUserAttributes\x10\x31\x1a%\x82\xd6\x1b!\n\x1fInFlightOps/AlterUserAttributes\x12\x37\n\x1d\x43OUNTER_USER_ATTRIBUTES_COUNT\x10\x32\x1a\x14\x82\xd6\x1b\x10\n\x0eUserAttributes\x12P\n(COUNTER_IN_FLIGHT_OPS_TxCreateTableIndex\x10\x33\x1a\"\x82\xd6\x1b\x1e\n\x1cInFlightOps/CreateTableIndex\x12\x33\n\x1b\x43OUNTER_TABLE_INDEXES_COUNT\x10\x34\x1a\x12\x82\xd6\x1b\x0e\n\x0cTableIndexes\x12O\n)COUNTER_BLOCKSTORE_PARTITION2_SHARD_COUNT\x10\x35\x1a \x82\xd6\x1b\x1c\n\x1a\x42lockStorePartition2Shards\x12L\n&COUNTER_IN_FLIGHT_OPS_TxDropTableIndex\x10\x36\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/DropTableIndex\x12\x38\n\x1b\x43OUNTER_EXTSUB_DOMAIN_COUNT\x10\x37\x1a\x17\x82\xd6\x1b\x13\n\x11\x45xernalSubDomains\x12T\n*COUNTER_IN_FLIGHT_OPS_TxCreateExtSubDomain\x10\x38\x1a$\x82\xd6\x1b \n\x1eInFlightOps/CreateExtSubDomain\x12G\n%COUNTER_SUB_DOMAIN_SCHEME_SHARD_COUNT\x10\x39\x1a\x1c\x82\xd6\x1b\x18\n\x16SubDomainsSchemeShards\x12V\n+COUNTER_IN_FLIGHT_OPS_TxMergeTablePartition\x10:\x1a%\x82\xd6\x1b!\n\x1fInFlightOps/MergeTablePartition\x12R\n)COUNTER_IN_FLIGHT_OPS_TxAlterExtSubDomain\x10;\x1a#\x82\xd6\x1b\x1f\n\x1dInFlightOps/AlterExtSubDomain\x12Z\n-COUNTER_IN_FLIGHT_OPS_TxForceDropExtSubDomain\x10<\x1a\'\x82\xd6\x1b#\n!InFlightOps/ForceDropExtSubDomain\x12\x42\n!COUNTER_IN_FLIGHT_OPS_TxFillIndex\x10=\x1a\x1b\x82\xd6\x1b\x17\n\x15InFlightOps/FillIndex\x12P\n(COUNTER_IN_FLIGHT_OPS_TxUpgradeSubDomain\x10>\x1a\"\x82\xd6\x1b\x1e\n\x1cInFlightOps/UpgradeSubDomain\x12`\n0COUNTER_IN_FLIGHT_OPS_TxUpgradeSubDomainDecision\x10?\x1a*\x82\xd6\x1b&\n$InFlightOps/UpgradeSubDomainDecision\x12\x38\n\x1d\x43OUNTER_SUB_DOMAIN_HIVE_COUNT\x10@\x1a\x15\x82\xd6\x1b\x11\n\x0fSubDomainsHives\x12X\n,COUNTER_IN_FLIGHT_OPS_TxInitializeBuildIndex\x10\x41\x1a&\x82\xd6\x1b\"\n InFlightOps/InitializeBuildIndex\x12,\n\x17\x43OUNTER_SNAPSHOTS_COUNT\x10\x42\x1a\x0f\x82\xd6\x1b\x0b\n\tSnapshots\x12$\n\x13\x43OUNTER_LOCKS_COUNT\x10\x43\x1a\x0b\x82\xd6\x1b\x07\n\x05Locks\x12\x44\n\"COUNTER_IN_FLIGHT_OPS_TxCreateLock\x10\x44\x1a\x1c\x82\xd6\x1b\x18\n\x16InFlightOps/CreateLock\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxAlterTableIndex\x10\x45\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/AlterTableIndex\x12T\n*COUNTER_IN_FLIGHT_OPS_TxFinalizeBuildIndex\x10\x46\x1a$\x82\xd6\x1b \n\x1eInFlightOps/FinalizeBuildIndex\x12T\n*COUNTER_IN_FLIGHT_OPS_TxAlterSolomonVolume\x10G\x1a$\x82\xd6\x1b \n\x1eInFlightOps/AlterSolomonVolume\x12@\n COUNTER_IN_FLIGHT_OPS_TxDropLock\x10H\x1a\x1a\x82\xd6\x1b\x16\n\x14InFlightOps/DropLock\x12\x62\n1COUNTER_IN_FLIGHT_OPS_TxDropTableIndexAtMainTable\x10I\x1a+\x82\xd6\x1b\'\n%InFlightOps/DropTableIndexAtMainTable\x12=\n COUNTER_SYS_VIEW_PROCESSOR_COUNT\x10J\x1a\x17\x82\xd6\x1b\x13\n\x11SysViewProcessors\x12-\n\x17\x43OUNTER_FILESTORE_COUNT\x10K\x1a\x10\x82\xd6\x1b\x0c\n\nFileStores\x12\x38\n\x1d\x43OUNTER_FILESTORE_SHARD_COUNT\x10L\x1a\x15\x82\xd6\x1b\x11\n\x0f\x46ileStoreShards\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxCreateFileStore\x10M\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/CreateFileStore\x12L\n&COUNTER_IN_FLIGHT_OPS_TxAlterFileStore\x10N\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/AlterFileStore\x12J\n%COUNTER_IN_FLIGHT_OPS_TxDropFileStore\x10O\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/DropFileStore\x12;\n\x1f\x43OUNTER_TTL_ENABLED_TABLE_COUNT\x10P\x1a\x16\x82\xd6\x1b\x12\n\x10TTLEnabledTables\x12>\n\x1f\x43OUNTER_IN_FLIGHT_OPS_TxRestore\x10Q\x1a\x19\x82\xd6\x1b\x15\n\x13InFlightOps/Restore\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxCreateOlapStore\x10R\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/CreateOlapStore\x12L\n&COUNTER_IN_FLIGHT_OPS_TxAlterOlapStore\x10S\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/AlterOlapStore\x12J\n%COUNTER_IN_FLIGHT_OPS_TxDropOlapStore\x10T\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/DropOlapStore\x12R\n)COUNTER_IN_FLIGHT_OPS_TxCreateColumnTable\x10U\x1a#\x82\xd6\x1b\x1f\n\x1dInFlightOps/CreateColumnTable\x12P\n(COUNTER_IN_FLIGHT_OPS_TxAlterColumnTable\x10V\x1a\"\x82\xd6\x1b\x1e\n\x1cInFlightOps/AlterColumnTable\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxDropColumnTable\x10W\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/DropColumnTable\x12.\n\x18\x43OUNTER_OLAP_STORE_COUNT\x10X\x1a\x10\x82\xd6\x1b\x0c\n\nOlapStores\x12\x32\n\x1a\x43OUNTER_COLUMN_TABLE_COUNT\x10Y\x1a\x12\x82\xd6\x1b\x0e\n\x0c\x43olumnTables\x12/\n\x15\x43OUNTER_DEPRECATED_90\x10Z\x1a\x14\x82\xd6\x1b\x10\n\x0eOlapMetaShards\x12-\n\x15\x43OUNTER_COLUMN_SHARDS\x10[\x1a\x12\x82\xd6\x1b\x0e\n\x0c\x43olumnShards\x12H\n$COUNTER_DISK_SPACE_TABLES_DATA_BYTES\x10\\\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x44iskSpaceTablesDataBytes\x12J\n%COUNTER_DISK_SPACE_TABLES_INDEX_BYTES\x10]\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x44iskSpaceTablesIndexBytes\x12J\n%COUNTER_DISK_SPACE_TABLES_TOTAL_BYTES\x10^\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x44iskSpaceTablesTotalBytes\x12\x43\n!COUNTER_DISK_SPACE_QUOTA_EXCEEDED\x10_\x1a\x1c\x82\xd6\x1b\x18\n\x16\x44iskSpaceQuotaExceeded\x12\x46\n#COUNTER_DISK_SPACE_HARD_QUOTA_BYTES\x10`\x1a\x1d\x82\xd6\x1b\x19\n\x17\x44iskSpaceHardQuotaBytes\x12\x46\n#COUNTER_DISK_SPACE_SOFT_QUOTA_BYTES\x10\x61\x1a\x1d\x82\xd6\x1b\x19\n\x17\x44iskSpaceSoftQuotaBytes\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxCreateCdcStream\x10\x62\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/CreateCdcStream\x12\\\n.COUNTER_IN_FLIGHT_OPS_TxCreateCdcStreamAtTable\x10\x63\x1a(\x82\xd6\x1b$\n\"InFlightOps/CreateCdcStreamAtTable\x12L\n&COUNTER_IN_FLIGHT_OPS_TxAlterCdcStream\x10\x64\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/AlterCdcStream\x12Z\n-COUNTER_IN_FLIGHT_OPS_TxAlterCdcStreamAtTable\x10\x65\x1a\'\x82\xd6\x1b#\n!InFlightOps/AlterCdcStreamAtTable\x12J\n%COUNTER_IN_FLIGHT_OPS_TxDropCdcStream\x10\x66\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/DropCdcStream\x12X\n,COUNTER_IN_FLIGHT_OPS_TxDropCdcStreamAtTable\x10g\x1a&\x82\xd6\x1b\"\n InFlightOps/DropCdcStreamAtTable\x12/\n\x19\x43OUNTER_CDC_STREAMS_COUNT\x10h\x1a\x10\x82\xd6\x1b\x0c\n\nCdcStreams\x12\x42\n!COUNTER_IN_FLIGHT_OPS_TxMoveTable\x10i\x1a\x1b\x82\xd6\x1b\x17\n\x15InFlightOps/MoveTable\x12L\n&COUNTER_IN_FLIGHT_OPS_TxMoveTableIndex\x10j\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/MoveTableIndex\x12+\n\x16\x43OUNTER_SEQUENCE_COUNT\x10k\x1a\x0f\x82\xd6\x1b\x0b\n\tSequences\x12\x35\n\x1b\x43OUNTER_SEQUENCESHARD_COUNT\x10l\x1a\x14\x82\xd6\x1b\x10\n\x0eSequenceShards\x12L\n&COUNTER_IN_FLIGHT_OPS_TxCreateSequence\x10m\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/CreateSequence\x12J\n%COUNTER_IN_FLIGHT_OPS_TxAlterSequence\x10n\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/AlterSequence\x12H\n$COUNTER_IN_FLIGHT_OPS_TxDropSequence\x10o\x1a\x1e\x82\xd6\x1b\x1a\n\x18InFlightOps/DropSequence\x12\x38\n\x1b\x43OUNTER_STREAM_SHARDS_COUNT\x10p\x1a\x17\x82\xd6\x1b\x13\n\x11StreamShardsCount\x12\x38\n\x1b\x43OUNTER_STREAM_SHARDS_QUOTA\x10q\x1a\x17\x82\xd6\x1b\x13\n\x11StreamShardsQuota\x12\x46\n\x1d\x43OUNTER_COMPACTION_QUEUE_SIZE\x10r\x1a#\x82\xd6\x1b\x1f\n\x1d\x42\x61\x63kgroundCompactionQueueSize\x12\x46\n\"COUNTER_STREAM_RESERVED_THROUGHPUT\x10s\x1a\x1e\x82\xd6\x1b\x1a\n\x18StreamReservedThroughput\x12@\n\x1f\x43OUNTER_STREAM_RESERVED_STORAGE\x10t\x1a\x1b\x82\xd6\x1b\x17\n\x15StreamReservedStorage\x12K\n%COUNTER_STREAM_RESERVED_STORAGE_QUOTA\x10u\x1a \x82\xd6\x1b\x1c\n\x1aStreamReservedStorageQuota\x12\x31\n\x19\x43OUNTER_REPLICATION_COUNT\x10v\x1a\x12\x82\xd6\x1b\x0e\n\x0cReplications\x12\x46\n$COUNTER_REPLICATION_CONTROLLER_COUNT\x10w\x1a\x1c\x82\xd6\x1b\x18\n\x16ReplicationControllers\x12R\n)COUNTER_IN_FLIGHT_OPS_TxCreateReplication\x10x\x1a#\x82\xd6\x1b\x1f\n\x1dInFlightOps/CreateReplication\x12P\n(COUNTER_IN_FLIGHT_OPS_TxAlterReplication\x10y\x1a\"\x82\xd6\x1b\x1e\n\x1cInFlightOps/AlterReplication\x12N\n\'COUNTER_IN_FLIGHT_OPS_TxDropReplication\x10z\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/DropReplication\x12W\n COUNTER_COMPACTION_QUEUE_SIZE_SH\x10{\x1a\x31\x82\xd6\x1b-\n+BackgroundCompactionQueueSizeBySearchHeight\x12Z\n%COUNTER_COMPACTION_QUEUE_SIZE_DELETES\x10|\x1a/\x82\xd6\x1b+\n)BackgroundCompactionQueueSizeByRowDeletes\x12L\n COUNTER_COMPACTION_QUEUE_RUNNING\x10}\x1a&\x82\xd6\x1b\"\n BackgroundCompactionQueueRunning\x12Y\n\'COUNTER_COMPACTION_QUEUE_WAITING_REPEAT\x10~\x1a,\x82\xd6\x1b(\n&BackgroundCompactionQueueWaitingRepeat\x12H\n!COUNTER_SHARDS_WITH_BORROWED_DATA\x10\x7f\x1a!\x82\xd6\x1b\x1d\n\x1bTableShardsWithBorrowedData\x12\x45\n\x1f\x43OUNTER_SHARDS_WITH_LOANED_DATA\x10\x80\x01\x1a\x1f\x82\xd6\x1b\x1b\n\x19TableShardsWithLoanedData\x12N\n&COUNTER_BORROWED_COMPACTION_QUEUE_SIZE\x10\x81\x01\x1a!\x82\xd6\x1b\x1d\n\x1b\x42orrowedCompactionQueueSize\x12T\n)COUNTER_BORROWED_COMPACTION_QUEUE_RUNNING\x10\x82\x01\x1a$\x82\xd6\x1b \n\x1e\x42orrowedCompactionQueueRunning\x12/\n\x18\x43OUNTER_BLOB_DEPOT_COUNT\x10\x83\x01\x1a\x10\x82\xd6\x1b\x0c\n\nBlobDepots\x12:\n\x1e\x43OUNTER_BLOB_DEPOT_SHARD_COUNT\x10\x84\x01\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42lobDepotShards\x12O\n\'COUNTER_IN_FLIGHT_OPS_TxCreateBlobDepot\x10\x85\x01\x1a!\x82\xd6\x1b\x1d\n\x1bInFlightOps/CreateBlobDepot\x12M\n&COUNTER_IN_FLIGHT_OPS_TxAlterBlobDepot\x10\x86\x01\x1a \x82\xd6\x1b\x1c\n\x1aInFlightOps/AlterBlobDepot\x12K\n%COUNTER_IN_FLIGHT_OPS_TxDropBlobDepot\x10\x87\x01\x1a\x1f\x82\xd6\x1b\x1b\n\x19InFlightOps/DropBlobDepot\x12\x33\n\x18\x43OUNTER_STATS_QUEUE_SIZE\x10\x88\x01\x1a\x14\x82\xd6\x1b\x10\n\x0eStatsQueueSize\x12\x65\n2COUNTER_IN_FLIGHT_OPS_TxUpdateMainTableOnIndexMove\x10\x89\x01\x1a,\x82\xd6\x1b(\n&InFlightOps/UpdateMainTableOnIndexMove\x12\x45\n\"COUNTER_IN_FLIGHT_OPS_TxAllocatePQ\x10\x8a\x01\x1a\x1c\x82\xd6\x1b\x18\n\x16InFlightOps/AllocatePQ\x12u\n:COUNTER_IN_FLIGHT_OPS_TxCreateCdcStreamAtTableWithSnapshot\x10\x8b\x01\x1a\x34\x82\xd6\x1b\x30\n.InFlightOps/CreateCdcStreamAtTableWithSnapshot\x12g\n3COUNTER_IN_FLIGHT_OPS_TxAlterExtSubDomainCreateHive\x10\x8c\x01\x1a-\x82\xd6\x1b)\n\'InFlightOps/AlterExtSubDomainCreateHive*\xac\x34\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00\x12=\n\x1e\x43OUNTER_FINISHED_OPS_TxInvalid\x10\x01\x1a\x19\x82\xd6\x1b\x15\n\x13\x46inishedOps/Invalid\x12\x39\n\x1c\x43OUNTER_FINISHED_OPS_TxMkDir\x10\x02\x1a\x17\x82\xd6\x1b\x13\n\x11\x46inishedOps/MkDir\x12\x45\n\"COUNTER_FINISHED_OPS_TxCreateTable\x10\x03\x1a\x1d\x82\xd6\x1b\x19\n\x17\x46inishedOps/CreateTable\x12I\n$COUNTER_FINISHED_OPS_TxCreatePQGroup\x10\x04\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/CreatePQGroup\x12G\n#COUNTER_FINISHED_OPS_TxAlterPQGroup\x10\x05\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x46inishedOps/AlterPQGroup\x12\x43\n!COUNTER_FINISHED_OPS_TxAlterTable\x10\x06\x1a\x1c\x82\xd6\x1b\x18\n\x16\x46inishedOps/AlterTable\x12\x41\n COUNTER_FINISHED_OPS_TxDropTable\x10\x07\x1a\x1b\x82\xd6\x1b\x17\n\x15\x46inishedOps/DropTable\x12\x45\n\"COUNTER_FINISHED_OPS_TxDropPQGroup\x10\x08\x1a\x1d\x82\xd6\x1b\x19\n\x17\x46inishedOps/DropPQGroup\x12\x41\n COUNTER_FINISHED_OPS_TxModifyACL\x10\t\x1a\x1b\x82\xd6\x1b\x17\n\x15\x46inishedOps/ModifyACL\x12\x39\n\x1c\x43OUNTER_FINISHED_OPS_TxRmDir\x10\n\x1a\x17\x82\xd6\x1b\x13\n\x11\x46inishedOps/RmDir\x12\x41\n COUNTER_FINISHED_OPS_TxCopyTable\x10\x0b\x1a\x1b\x82\xd6\x1b\x17\n\x15\x46inishedOps/CopyTable\x12U\n*COUNTER_FINISHED_OPS_TxSplitTablePartition\x10\x0c\x1a%\x82\xd6\x1b!\n\x1f\x46inishedOps/SplitTablePartition\x12;\n\x1d\x43OUNTER_FINISHED_OPS_TxBackup\x10\r\x1a\x18\x82\xd6\x1b\x14\n\x12\x46inishedOps/Backup\x12M\n&COUNTER_FINISHED_OPS_TxCreateSubDomain\x10\x0e\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/CreateSubDomain\x12I\n$COUNTER_FINISHED_OPS_TxDropSubDomain\x10\x0f\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/DropSubDomain\x12O\n\'COUNTER_FINISHED_OPS_TxCreateRtmrVolume\x10\x10\x1a\"\x82\xd6\x1b\x1e\n\x1c\x46inishedOps/CreateRtmrVolume\x12[\n-COUNTER_FINISHED_OPS_TxCreateBlockStoreVolume\x10\x11\x1a(\x82\xd6\x1b$\n\"FinishedOps/CreateBlockStoreVolume\x12Y\n,COUNTER_FINISHED_OPS_TxAlterBlockStoreVolume\x10\x12\x1a\'\x82\xd6\x1b#\n!FinishedOps/AlterBlockStoreVolume\x12[\n-COUNTER_FINISHED_OPS_TxAssignBlockStoreVolume\x10\x13\x1a(\x82\xd6\x1b$\n\"FinishedOps/AssignBlockStoreVolume\x12W\n+COUNTER_FINISHED_OPS_TxDropBlockStoreVolume\x10\x14\x1a&\x82\xd6\x1b\"\n FinishedOps/DropBlockStoreVolume\x12;\n\x1c\x43OUNTER_FINISHED_OPS_UNKNOWN\x10\x15\x1a\x19\x82\xd6\x1b\x15\n\x13\x46inishedOps/UNKNOWN\x12\x45\n\"COUNTER_FINISHED_OPS_TxCreateKesus\x10\x16\x1a\x1d\x82\xd6\x1b\x19\n\x17\x46inishedOps/CreateKesus\x12\x41\n COUNTER_FINISHED_OPS_TxDropKesus\x10\x17\x1a\x1b\x82\xd6\x1b\x17\n\x15\x46inishedOps/DropKesus\x12S\n)COUNTER_FINISHED_OPS_TxForceDropSubDomain\x10\x18\x1a$\x82\xd6\x1b \n\x1e\x46inishedOps/ForceDropSubDomain\x12U\n*COUNTER_FINISHED_OPS_TxCreateSolomonVolume\x10\x19\x1a%\x82\xd6\x1b!\n\x1f\x46inishedOps/CreateSolomonVolume\x12Q\n(COUNTER_FINISHED_OPS_TxDropSolomonVolume\x10\x1a\x1a#\x82\xd6\x1b\x1f\n\x1d\x46inishedOps/DropSolomonVolume\x12\x43\n!COUNTER_FINISHED_OPS_TxAlterKesus\x10\x1b\x1a\x1c\x82\xd6\x1b\x18\n\x16\x46inishedOps/AlterKesus\x12K\n%COUNTER_FINISHED_OPS_TxAlterSubDomain\x10\x1c\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/AlterSubDomain\x12U\n*COUNTER_FINISHED_OPS_TxAlterUserAttributes\x10\x1d\x1a%\x82\xd6\x1b!\n\x1f\x46inishedOps/AlterUserAttributes\x12O\n\'COUNTER_FINISHED_OPS_TxCreateTableIndex\x10\x1e\x1a\"\x82\xd6\x1b\x1e\n\x1c\x46inishedOps/CreateTableIndex\x12K\n%COUNTER_FINISHED_OPS_TxDropTableIndex\x10\x1f\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/DropTableIndex\x12S\n)COUNTER_FINISHED_OPS_TxCreateExtSubDomain\x10 \x1a$\x82\xd6\x1b \n\x1e\x46inishedOps/CreateExtSubDomain\x12U\n*COUNTER_FINISHED_OPS_TxMergeTablePartition\x10!\x1a%\x82\xd6\x1b!\n\x1f\x46inishedOps/MergeTablePartition\x12Q\n(COUNTER_FINISHED_OPS_TxAlterExtSubDomain\x10\"\x1a#\x82\xd6\x1b\x1f\n\x1d\x46inishedOps/AlterExtSubDomain\x12Y\n,COUNTER_FINISHED_OPS_TxForceDropExtSubDomain\x10#\x1a\'\x82\xd6\x1b#\n!FinishedOps/ForceDropExtSubDomain\x12\x41\n COUNTER_FINISHED_OPS_TxFillIndex\x10$\x1a\x1b\x82\xd6\x1b\x17\n\x15\x46inishedOps/FillIndex\x12O\n\'COUNTER_FINISHED_OPS_TxUpgradeSubDomain\x10%\x1a\"\x82\xd6\x1b\x1e\n\x1c\x46inishedOps/UpgradeSubDomain\x12_\n/COUNTER_FINISHED_OPS_TxUpgradeSubDomainDecision\x10&\x1a*\x82\xd6\x1b&\n$FinishedOps/UpgradeSubDomainDecision\x12W\n+COUNTER_FINISHED_OPS_TxInitializeBuildIndex\x10\'\x1a&\x82\xd6\x1b\"\n FinishedOps/InitializeBuildIndex\x12\x43\n!COUNTER_FINISHED_OPS_TxCreateLock\x10(\x1a\x1c\x82\xd6\x1b\x18\n\x16\x46inishedOps/CreateLock\x12M\n&COUNTER_FINISHED_OPS_TxAlterTableIndex\x10)\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/AlterTableIndex\x12S\n)COUNTER_FINISHED_OPS_TxFinalizeBuildIndex\x10*\x1a$\x82\xd6\x1b \n\x1e\x46inishedOps/FinalizeBuildIndex\x12S\n)COUNTER_FINISHED_OPS_TxAlterSolomonVolume\x10+\x1a$\x82\xd6\x1b \n\x1e\x46inishedOps/AlterSolomonVolume\x12?\n\x1f\x43OUNTER_FINISHED_OPS_TxDropLock\x10,\x1a\x1a\x82\xd6\x1b\x16\n\x14\x46inishedOps/DropLock\x12\x61\n0COUNTER_FINISHED_OPS_TxDropTableIndexAtMainTable\x10-\x1a+\x82\xd6\x1b\'\n%FinishedOps/DropTableIndexAtMainTable\x12M\n&COUNTER_FINISHED_OPS_TxCreateFileStore\x10.\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/CreateFileStore\x12K\n%COUNTER_FINISHED_OPS_TxAlterFileStore\x10/\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/AlterFileStore\x12I\n$COUNTER_FINISHED_OPS_TxDropFileStore\x10\x30\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/DropFileStore\x12=\n\x1e\x43OUNTER_FINISHED_OPS_TxRestore\x10\x31\x1a\x19\x82\xd6\x1b\x15\n\x13\x46inishedOps/Restore\x12M\n&COUNTER_FINISHED_OPS_TxCreateOlapStore\x10\x32\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/CreateOlapStore\x12K\n%COUNTER_FINISHED_OPS_TxAlterOlapStore\x10\x33\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/AlterOlapStore\x12I\n$COUNTER_FINISHED_OPS_TxDropOlapStore\x10\x34\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/DropOlapStore\x12Q\n(COUNTER_FINISHED_OPS_TxCreateColumnTable\x10\x35\x1a#\x82\xd6\x1b\x1f\n\x1d\x46inishedOps/CreateColumnTable\x12O\n\'COUNTER_FINISHED_OPS_TxAlterColumnTable\x10\x36\x1a\"\x82\xd6\x1b\x1e\n\x1c\x46inishedOps/AlterColumnTable\x12M\n&COUNTER_FINISHED_OPS_TxDropColumnTable\x10\x37\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/DropColumnTable\x12M\n&COUNTER_FINISHED_OPS_TxCreateCdcStream\x10\x38\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/CreateCdcStream\x12[\n-COUNTER_FINISHED_OPS_TxCreateCdcStreamAtTable\x10\x39\x1a(\x82\xd6\x1b$\n\"FinishedOps/CreateCdcStreamAtTable\x12K\n%COUNTER_FINISHED_OPS_TxAlterCdcStream\x10:\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/AlterCdcStream\x12Y\n,COUNTER_FINISHED_OPS_TxAlterCdcStreamAtTable\x10;\x1a\'\x82\xd6\x1b#\n!FinishedOps/AlterCdcStreamAtTable\x12I\n$COUNTER_FINISHED_OPS_TxDropCdcStream\x10<\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/DropCdcStream\x12W\n+COUNTER_FINISHED_OPS_TxDropCdcStreamAtTable\x10=\x1a&\x82\xd6\x1b\"\n FinishedOps/DropCdcStreamAtTable\x12\x41\n COUNTER_FINISHED_OPS_TxMoveTable\x10>\x1a\x1b\x82\xd6\x1b\x17\n\x15\x46inishedOps/MoveTable\x12K\n%COUNTER_FINISHED_OPS_TxMoveTableIndex\x10?\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/MoveTableIndex\x12K\n%COUNTER_FINISHED_OPS_TxCreateSequence\x10@\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/CreateSequence\x12I\n$COUNTER_FINISHED_OPS_TxAlterSequence\x10\x41\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/AlterSequence\x12G\n#COUNTER_FINISHED_OPS_TxDropSequence\x10\x42\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x46inishedOps/DropSequence\x12J\n$COUNTER_BACKGROUND_COMPACTION_FAILED\x10\x43\x1a \x82\xd6\x1b\x1c\n\x1a\x42\x61\x63kgroundCompactionFailed\x12\x42\n COUNTER_BACKGROUND_COMPACTION_OK\x10\x44\x1a\x1c\x82\xd6\x1b\x18\n\x16\x42\x61\x63kgroundCompactionOK\x12L\n%COUNTER_BACKGROUND_COMPACTION_TIMEOUT\x10\x45\x1a!\x82\xd6\x1b\x1d\n\x1b\x42\x61\x63kgroundCompactionTimeout\x12Q\n(COUNTER_FINISHED_OPS_TxCreateReplication\x10\x46\x1a#\x82\xd6\x1b\x1f\n\x1d\x46inishedOps/CreateReplication\x12O\n\'COUNTER_FINISHED_OPS_TxAlterReplication\x10G\x1a\"\x82\xd6\x1b\x1e\n\x1c\x46inishedOps/AlterReplication\x12M\n&COUNTER_FINISHED_OPS_TxDropReplication\x10H\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/DropReplication\x12N\n&COUNTER_BACKGROUND_COMPACTION_BORROWED\x10I\x1a\"\x82\xd6\x1b\x1e\n\x1c\x42\x61\x63kgroundCompactionBorrowed\x12Q\n(COUNTER_BACKGROUND_COMPACTION_NOT_NEEDED\x10J\x1a#\x82\xd6\x1b\x1f\n\x1d\x42\x61\x63kgroundCompactionNotNeeded\x12J\n$COUNTER_BACKGROUND_COMPACTION_LOANED\x10K\x1a \x82\xd6\x1b\x1c\n\x1a\x42\x61\x63kgroundCompactionLoaned\x12>\n\x1e\x43OUNTER_BORROWED_COMPACTION_OK\x10L\x1a\x1a\x82\xd6\x1b\x16\n\x14\x42orrowedCompactionOK\x12H\n#COUNTER_BORROWED_COMPACTION_TIMEOUT\x10M\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x42orrowedCompactionTimeout\x12M\n&COUNTER_FINISHED_OPS_TxCreateBlobDepot\x10N\x1a!\x82\xd6\x1b\x1d\n\x1b\x46inishedOps/CreateBlobDepot\x12K\n%COUNTER_FINISHED_OPS_TxAlterBlobDepot\x10O\x1a \x82\xd6\x1b\x1c\n\x1a\x46inishedOps/AlterBlobDepot\x12I\n$COUNTER_FINISHED_OPS_TxDropBlobDepot\x10P\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x46inishedOps/DropBlobDepot\x12-\n\x15\x43OUNTER_STATS_WRITTEN\x10Q\x1a\x12\x82\xd6\x1b\x0e\n\x0cStatsWritten\x12\x63\n1COUNTER_FINISHED_OPS_TxUpdateMainTableOnIndexMove\x10R\x1a,\x82\xd6\x1b(\n&FinishedOps/UpdateMainTableOnIndexMove\x12\x43\n!COUNTER_FINISHED_OPS_TxAllocatePQ\x10S\x1a\x1c\x82\xd6\x1b\x18\n\x16\x46inishedOps/AllocatePQ\x12s\n9COUNTER_FINISHED_OPS_TxCreateCdcStreamAtTableWithSnapshot\x10T\x1a\x34\x82\xd6\x1b\x30\n.FinishedOps/CreateCdcStreamAtTableWithSnapshot\x12\x65\n2COUNTER_FINISHED_OPS_TxAlterExtSubDomainCreateHive\x10U\x1a-\x82\xd6\x1b)\n\'FinishedOps/AlterExtSubDomainCreateHive*\x9a\n\n\x13\x45PercentileCounters\x12Q\n(COUNTER_BACKGROUND_COMPACTION_OK_LATENCY\x10\x00\x1a#\x82\xd6\x1b\x1f\n\x1d\x42\x61\x63kgroundCompactionOkLatency\x12\xa1\x01\n\x1d\x43OUNTER_NUM_SHARDS_BY_TTL_LAG\x10\x01\x1a~\x82\xd6\x1bz\n\x11NumShardsByTtlLag\x12\x05\x08\x00\x12\x01\x30\x12\x08\x08\x84\x07\x12\x03\x39\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\x80\xe1\x01\x12\x05\x32\x38\x38\x30\x30\x12\x0b\x08\x80\xc2\x03\x12\x05\x35\x37\x36\x30\x30\x12\x0b\x08\x80\xa3\x05\x12\x05\x38\x36\x34\x30\x30\x18\x01\x12\xc5\x01\n!COUNTER_SHARDS_WITH_SEARCH_HEIGHT\x10\x02\x1a\x9d\x01\x82\xd6\x1b\x98\x01\n\x16ShardsWithSearchHeight\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x03\x12\x01\x33\x12\x05\x08\x04\x12\x01\x34\x12\x05\x08\x05\x12\x01\x35\x12\x05\x08\x06\x12\x01\x36\x12\x05\x08\x07\x12\x01\x37\x12\x05\x08\x08\x12\x01\x38\x12\x05\x08\t\x12\x01\x39\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x0b\x12\x02\x31\x31\x12\x06\x08\x0c\x12\x02\x31\x32\x12\x06\x08\r\x12\x02\x31\x33\x12\x06\x08\x0e\x12\x02\x31\x34\x12\x06\x08\x0f\x12\x02\x31\x35\x12\x06\x08\x14\x12\x02\x32\x30\x18\x01\x12\x8c\x01\n#COUNTER_SHARDS_WITH_FULL_COMPACTION\x10\x03\x1a\x63\x82\xd6\x1b_\n\x1cShardsFullCompactionAgeHours\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x06\x12\x01\x36\x12\x06\x08\x0c\x12\x02\x31\x32\x12\x06\x08\x18\x12\x02\x32\x34\x12\x06\x08\x30\x12\x02\x34\x38\x12\x06\x08H\x12\x02\x37\x32\x12\x08\x08\xa8\x01\x12\x03\x31\x36\x38\x18\x01\x12\xbe\x01\n\x1f\x43OUNTER_SHARDS_WITH_ROW_DELETES\x10\x04\x1a\x98\x01\x82\xd6\x1b\x93\x01\n\x14ShardsWithRowDeletes\x12\x05\x08\x00\x12\x01\x30\x12\x07\x08\x64\x12\x03\x31\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\x0c\x08\xa0\x8d\x06\x12\x06\x31\x30\x30\x30\x30\x30\x12\r\x08\xc0\x84=\x12\x07\x31\x30\x30\x30\x30\x30\x30\x12\x0f\x08\x80\xad\xe2\x04\x12\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12\x10\x08\x80\xc2\xd7/\x12\t100000000\x12\x12\x08\x80\x94\xeb\xdc\x03\x12\n1000000000\x18\x01\x12\x95\x01\n\x1b\x43OUNTER_STATS_BATCH_LATENCY\x10\x05\x1at\x82\xd6\x1bp\n\x11StatsBatchLatency\x12\t\x08\xe8\x07\x12\x04\x31 ms\x12\n\x08\x90N\x12\x05\x31\x30 ms\x12\x0b\x08\xd0\x86\x03\x12\x05\x35\x30 ms\x12\x0c\x08\xa0\x8d\x06\x12\x06\x31\x30\x30 ms\x12\x0c\x08\xc0\x9a\x0c\x12\x06\x32\x30\x30 ms\x12\x0c\x08\xa0\xc2\x1e\x12\x06\x35\x30\x30 ms\x12\r\x08\xc0\x84=\x12\x07\x31\x30\x30\x30 ms\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s*\xec\'\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12&\n\x10TXTYPE_INIT_ROOT\x10\x01\x1a\x10\x8a\xd6\x1b\x0c\n\nTxInitRoot\x12&\n\x10TXTYPE_PLAN_STEP\x10\x02\x1a\x10\x8a\xd6\x1b\x0c\n\nTxPlanStep\x12\x32\n\x16TXTYPE_DESCRIBE_SCHEME\x10\x03\x1a\x16\x8a\xd6\x1b\x12\n\x10TxDescribeScheme\x12\x43\n\x1fTXTYPE_DATASHARD_PROPOSE_RESULT\x10\x04\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxDataShardProposeResult\x12\x39\n\x1aTXTYPE_CREATE_TABLET_REPLY\x10\x05\x1a\x19\x8a\xd6\x1b\x15\n\x13TxCreateTabletReply\x12*\n\x12TXTYPE_PROGRESS_OP\x10\x06\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxProgressOp\x12\x41\n\x1eTXTYPE_PERSQUEUE_CONFIG_RESULT\x10\x07\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxPersQueueConfigResult\x12\x37\n\x19TXTYPE_DROP_TABLET_RESULT\x10\x08\x1a\x18\x8a\xd6\x1b\x14\n\x12TxDropTabletResult\x12\x37\n\x19TXTYPE_FREE_TABLET_RESULT\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxFreeTabletResult\x12?\n\x1dTXTYPE_DATASHARD_STATE_RESULT\x10\n\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxDataShardStateResult\x12\x36\n\x19TXTYPE_INIT_SPLIT_DST_ACK\x10\x0b\x1a\x17\x8a\xd6\x1b\x13\n\x11TxInitSplitDstAck\x12&\n\x10TXTYPE_SPLIT_ACK\x10\x0c\x1a\x10\x8a\xd6\x1b\x0c\n\nTxSplitAck\x12R\n)TXTYPE_SPLIT_PARTITIONING_CHANGED_DST_ACK\x10\r\x1a#\x8a\xd6\x1b\x1f\n\x1dTxSplitPartitioningChangedAck\x12\x37\n\x19TXTYPE_CANCEL_BACKUP_IMPL\x10\x0e\x1a\x18\x8a\xd6\x1b\x14\n\x12TxCancelBackupImpl\x12)\n\x11TXTYPE_MONITORING\x10\x0f\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonitoring\x12H\n!TXTYPE_SUBDOMAIN_CONFIGURE_RESULT\x10\x10\x1a!\x8a\xd6\x1b\x1d\n\x1bTTxSubDomainConfigureStatus\x12\x44\n\x1fTXTYPE_BLOCKSTORE_CONFIG_RESULT\x10\x11\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TTxBlockStoreConfigResult\x12:\n\x1aTXTYPE_KESUS_CONFIG_RESULT\x10\x12\x1a\x1a\x8a\xd6\x1b\x16\n\x14TTxKesusConfigResult\x12-\n\x0eTXTYPE_PROPOSE\x10\x13\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxOperationPropose\x12\x43\n\x1fTXTYPE_DATASHARD_SCHEMA_CHANGED\x10\x14\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxDataShardSchemaChanged\x12O\n&TXTYPE_DEFERRED_UPDATE_ON_SCHEME_BOARD\x10\x15\x1a#\x8a\xd6\x1b\x1f\n\x1dTxDeferredUpdateOnSchemeBoard\x12,\n\x13TXTYPE_CLEAN_TABLES\x10\x16\x1a\x13\x8a\xd6\x1b\x0f\n\rTxCleanTables\x12.\n\x14TXTYPE_CREATE_EXPORT\x10\x17\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCreateExport\x12(\n\x11TXTYPE_GET_EXPORT\x10\x18\x1a\x11\x8a\xd6\x1b\r\n\x0bTxGetExport\x12.\n\x14TXTYPE_CANCEL_EXPORT\x10\x19\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCancelExport\x12\x35\n\x18TXTYPE_CANCEL_EXPORT_ACK\x10\x1a\x1a\x17\x8a\xd6\x1b\x13\n\x11TxCancelExportAck\x12.\n\x14TXTYPE_FORGET_EXPORT\x10\x1b\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxForgetExport\x12,\n\x13TXTYPE_LIST_EXPORTS\x10\x1c\x1a\x13\x8a\xd6\x1b\x0f\n\rTxListExports\x12\x32\n\x16TXTYPE_EXPORT_PROGRESS\x10\x1d\x1a\x16\x8a\xd6\x1b\x12\n\x10TxExportProgress\x12*\n\x12TXTYPE_SYNC_TENANT\x10\x1e\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxSyncTenant\x12.\n\x14TXTYPE_UPDATE_TENANT\x10\x1f\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxUpdateTenant\x12\x44\n TXTYPE_FREE_OWNER_TABLETS_RESULT\x10 \x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxFreeOwnerTabletsResult\x12\x44\n\x1fTXTYPE_SUBDOMAIN_MIGRATE_RESULT\x10!\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TTxSubDomainMigrateResult\x12\x37\n\x18TXTYPE_SUBDOMAIN_MIGRATE\x10\"\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxSubDomainMigrate\x12\x31\n\x15TXTYPE_UPGRADE_SCHEME\x10#\x1a\x16\x8a\xd6\x1b\x12\n\x10TTxUpgradeScheme\x12\x31\n\x15TXTYPE_INIT_POPULATOR\x10$\x1a\x16\x8a\xd6\x1b\x12\n\x10TTxInitPopulator\x12\x37\n\x19TXTYPE_CREATE_INDEX_BUILD\x10%\x1a\x18\x8a\xd6\x1b\x14\n\x12TxCreateIndexBuild\x12\x31\n\x16TXTYPE_GET_INDEX_BUILD\x10&\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxGetIndexBuild\x12\x37\n\x19TXTYPE_CANCEL_INDEX_BUILD\x10\'\x1a\x18\x8a\xd6\x1b\x14\n\x12TxCancelIndexBuild\x12\x37\n\x19TXTYPE_FORGET_INDEX_BUILD\x10(\x1a\x18\x8a\xd6\x1b\x14\n\x12TxForgetIndexBuild\x12\x33\n\x17TXTYPE_LIST_INDEX_BUILD\x10)\x1a\x16\x8a\xd6\x1b\x12\n\x10TxListIndexBuild\x12;\n\x1bTXTYPE_PROGRESS_INDEX_BUILD\x10*\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxProgressIndexBuild\x12G\n!TXTYPE_SCHEDULE_CONDITIONAL_ERASE\x10+\x1a \x8a\xd6\x1b\x1c\n\x1aTxScheduleConditionalErase\x12=\n\x1cTXTYPE_RUN_CONDITIONAL_ERASE\x10,\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxRunConditionalErase\x12=\n\x1cTXTYPE_STORE_PARTITION_STATS\x10-\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxStorePartitionStats\x12\x41\n\x1eTXTYPE_FILESTORE_CONFIG_RESULT\x10.\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxFileStoreConfigResult\x12:\n\x1bTXTYPE_MAKEBILL_INDEX_BUILD\x10/\x1a\x19\x8a\xd6\x1b\x15\n\x13TxBillingIndexBuild\x12.\n\x14TXTYPE_CREATE_IMPORT\x10\x30\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCreateImport\x12(\n\x11TXTYPE_GET_IMPORT\x10\x31\x1a\x11\x8a\xd6\x1b\r\n\x0bTxGetImport\x12.\n\x14TXTYPE_CANCEL_IMPORT\x10\x32\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCancelImport\x12\x35\n\x18TXTYPE_CANCEL_IMPORT_ACK\x10\x33\x1a\x17\x8a\xd6\x1b\x13\n\x11TxCancelImportAck\x12.\n\x14TXTYPE_FORGET_IMPORT\x10\x34\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxForgetImport\x12,\n\x13TXTYPE_LIST_IMPORTS\x10\x35\x1a\x13\x8a\xd6\x1b\x0f\n\rTxListImports\x12\x32\n\x16TXTYPE_IMPORT_PROGRESS\x10\x36\x1a\x16\x8a\xd6\x1b\x12\n\x10TxImportProgress\x12G\n!TXTYPE_SERVERLESS_STORAGE_BILLING\x10\x37\x1a \x8a\xd6\x1b\x1c\n\x1aTxServerlessStorageBilling\x12\x43\n\x1fTXTYPE_OLAPSHARD_PROPOSE_RESULT\x10\x38\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxOlapShardProposeResult\x12G\n!TXTYPE_COLUMNSHARD_PROPOSE_RESULT\x10\x39\x1a \x8a\xd6\x1b\x1c\n\x1aTxColumnShardProposeResult\x12[\n,TXTYPE_OLAPSHARD_NOTIFY_TX_COMPLETION_RESULT\x10:\x1a)\x8a\xd6\x1b%\n#TxOlapShardNotifyTxCompletionResult\x12_\n.TXTYPE_COLUMNSHARD_NOTIFY_TX_COMPLETION_RESULT\x10;\x1a+\x8a\xd6\x1b\'\n%TxColumnShardNotifyTxCompletionResult\x12K\n$TXTYPE_FIND_TABLET_SUBDOMAIN_PATH_ID\x10<\x1a!\x8a\xd6\x1b\x1d\n\x1bTxFindTabletSubDomainPathId\x12\x43\n\x1fTXTYPE_CLEAN_BLOCKSTORE_VOLUMES\x10=\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxCleanBlockStoreVolumes\x12\x39\n\x1aTXTYPE_CLEAN_DROPPED_PATHS\x10>\x1a\x19\x8a\xd6\x1b\x15\n\x13TxCleanDroppedPaths\x12\x43\n\x1fTXTYPE_CLEAN_DROPPED_SUBDOMAINS\x10?\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxCleanDroppedSubDomains\x12\x1f\n\x0cTXTYPE_LOGIN\x10@\x1a\r\x8a\xd6\x1b\t\n\x07TxLogin\x12Z\n+TXTYPE_SEQUENCESHARD_CREATE_SEQUENCE_RESULT\x10\x41\x1a)\x8a\xd6\x1b%\n#TxSequenceShardCreateSequenceResult\x12V\n)TXTYPE_SEQUENCESHARD_DROP_SEQUENCE_RESULT\x10\x42\x1a\'\x8a\xd6\x1b#\n!TxSequenceShardDropSequenceResult\x12Z\n+TXTYPE_SEQUENCESHARD_UPDATE_SEQUENCE_RESULT\x10\x43\x1a)\x8a\xd6\x1b%\n#TxSequenceShardUpdateSequenceResult\x12Z\n+TXTYPE_SEQUENCESHARD_FREEZE_SEQUENCE_RESULT\x10\x44\x1a)\x8a\xd6\x1b%\n#TxSequenceShardFreezeSequenceResult\x12\\\n,TXTYPE_SEQUENCESHARD_RESTORE_SEQUENCE_RESULT\x10\x45\x1a*\x8a\xd6\x1b&\n$TxSequenceShardRestoreSequenceResult\x12^\n-TXTYPE_SEQUENCESHARD_REDIRECT_SEQUENCE_RESULT\x10\x46\x1a+\x8a\xd6\x1b\'\n%TxSequenceShardRedirectSequenceResult\x12\\\n,TXTYPE_NOTIFY_OPERATION_COMPLETE_PUBLICATION\x10G\x1a*\x8a\xd6\x1b&\n$TxNotifyOperationCompletePublication\x12T\n(TXTYPE_NOTIFY_OPERATION_COMPLETE_BARRIER\x10H\x1a&\x8a\xd6\x1b\"\n TxNotifyOperationCompleteBarrier\x12:\n\x1aTXTYPE_PARTITION_HISTOGRAM\x10I\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxPartitionHistogram\x12\x45\n TXTYPE_CREATE_REPLICATION_RESULT\x10J\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxCreateReplicationResult\x12\x43\n\x1fTXTYPE_ALTER_REPLICATION_RESULT\x10K\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxAlterReplicationResult\x12\x41\n\x1eTXTYPE_DROP_REPLICATION_RESULT\x10L\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxDropReplicationResult\x12\x42\n\x1fTXTYPE_CREATE_BLOB_DEPOT_RESULT\x10M\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxCreateBlobDepotResult\x12@\n\x1eTXTYPE_ALTER_BLOB_DEPOT_RESULT\x10N\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxAlterBlobDepotResult\x12>\n\x1dTXTYPE_DROP_BLOB_DEPOT_RESULT\x10O\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxDropBlobDepotResult\x12\x42\n\x1fTXTYPE_BLOB_DEPOT_CONFIG_RESULT\x10P\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxBlobDepotConfigResult\x12\x46\n!TXTYPE_ADD_BACKGROUND_TASK_RESULT\x10Q\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxAddBackgroundTaskResultB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0bSchemeShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_schemeshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013SchemeShard'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._serialized_options = b'\202\326\033\026\n\024ResponseTimeMicrosec'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DIR_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DIR_COUNT"]._serialized_options = b'\202\326\033\r\n\013Directories'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_COUNT"]._serialized_options = b'\202\326\033\010\n\006Tables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_GROUP_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_GROUP_COUNT"]._serialized_options = b'\202\326\033\n\n\010PqGroups'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_SHARD_ACTIVE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_SHARD_ACTIVE_COUNT"]._serialized_options = b'\202\326\033\023\n\021TableShardsActive'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_SHARD_INACTIVE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_SHARD_INACTIVE_COUNT"]._serialized_options = b'\202\326\033\025\n\023TableShardsInactive'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_SHARD_COUNT"]._serialized_options = b'\202\326\033\017\n\rPqGroupShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_RB_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_RB_SHARD_COUNT"]._serialized_options = b'\202\326\033\026\n\024PqReadBalancerShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_COUNT"]._serialized_options = b'\202\326\033\014\n\nSubDomains'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_COORDINATOR_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_COORDINATOR_COUNT"]._serialized_options = b'\202\326\033\030\n\026SubDomainsCoordinators'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_MEDIATOR_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_MEDIATOR_COUNT"]._serialized_options = b'\202\326\033\025\n\023SubDomainsMediators'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RTMR_VOLUME_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RTMR_VOLUME_COUNT"]._serialized_options = b'\202\326\033\022\n\020RtmrVolumesCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RTMR_PARTITIONS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RTMR_PARTITIONS_COUNT"]._serialized_options = b'\202\326\033\025\n\023RtmrPartitionsCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_VOLUME_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_VOLUME_COUNT"]._serialized_options = b'\202\326\033\023\n\021BlockStoreVolumes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_VOLUME_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_VOLUME_SHARD_COUNT"]._serialized_options = b'\202\326\033\030\n\026BlockStoreVolumeShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_PARTITION_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_PARTITION_SHARD_COUNT"]._serialized_options = b'\202\326\033\033\n\031BlockStorePartitionShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxInvalid"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxInvalid"]._serialized_options = b'\202\326\033\025\n\023InFlightOps/Invalid'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMkDir"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMkDir"]._serialized_options = b'\202\326\033\023\n\021InFlightOps/MkDir'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateTable"]._serialized_options = b'\202\326\033\031\n\027InFlightOps/CreateTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreatePQGroup"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreatePQGroup"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/CreatePQGroup'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterPQGroup"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterPQGroup"]._serialized_options = b'\202\326\033\032\n\030InFlightOps/AlterPQGroup'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterTable"]._serialized_options = b'\202\326\033\030\n\026InFlightOps/AlterTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropTable"]._serialized_options = b'\202\326\033\027\n\025InFlightOps/DropTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropPQGroup"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropPQGroup"]._serialized_options = b'\202\326\033\031\n\027InFlightOps/DropPQGroup'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxModifyACL"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxModifyACL"]._serialized_options = b'\202\326\033\027\n\025InFlightOps/ModifyACL'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxRmDir"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxRmDir"]._serialized_options = b'\202\326\033\023\n\021InFlightOps/RmDir'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCopyTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCopyTable"]._serialized_options = b'\202\326\033\027\n\025InFlightOps/CopyTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxSplitTablePartition"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxSplitTablePartition"]._serialized_options = b'\202\326\033!\n\037InFlightOps/SplitTablePartition'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxBackup"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxBackup"]._serialized_options = b'\202\326\033\024\n\022InFlightOps/Backup'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateSubDomain"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/CreateSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropSubDomain"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/DropSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateRtmrVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateRtmrVolume"]._serialized_options = b'\202\326\033\036\n\034InFlightOps/CreateRtmrVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateBlockStoreVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateBlockStoreVolume"]._serialized_options = b'\202\326\033$\n\"InFlightOps/CreateBlockStoreVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterBlockStoreVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterBlockStoreVolume"]._serialized_options = b'\202\326\033#\n!InFlightOps/AlterBlockStoreVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAssignBlockStoreVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAssignBlockStoreVolume"]._serialized_options = b'\202\326\033$\n\"InFlightOps/AssignBlockStoreVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropBlockStoreVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropBlockStoreVolume"]._serialized_options = b'\202\326\033\"\n InFlightOps/DropBlockStoreVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_UNKNOWN"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_UNKNOWN"]._serialized_options = b'\202\326\033\025\n\023InFlightOps/UNKNOWN'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_KESUS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_KESUS_COUNT"]._serialized_options = b'\202\326\033\007\n\005Kesus'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_KESUS_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_KESUS_SHARD_COUNT"]._serialized_options = b'\202\326\033\r\n\013KesusShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateKesus"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateKesus"]._serialized_options = b'\202\326\033\031\n\027InFlightOps/CreateKesus'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropKesus"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropKesus"]._serialized_options = b'\202\326\033\027\n\025InFlightOps/DropKesus'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxForceDropSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxForceDropSubDomain"]._serialized_options = b'\202\326\033 \n\036InFlightOps/ForceDropSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateSolomonVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateSolomonVolume"]._serialized_options = b'\202\326\033!\n\037InFlightOps/CreateSolomonVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropSolomonVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropSolomonVolume"]._serialized_options = b'\202\326\033\037\n\035InFlightOps/DropSolomonVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SOLOMON_VOLUME_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SOLOMON_VOLUME_COUNT"]._serialized_options = b'\202\326\033\025\n\023SolomonVolumesCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SOLOMON_PARTITIONS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SOLOMON_PARTITIONS_COUNT"]._serialized_options = b'\202\326\033\030\n\026SolomonPartitionsCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterKesus"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterKesus"]._serialized_options = b'\202\326\033\030\n\026InFlightOps/AlterKesus'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterSubDomain"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/AlterSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterUserAttributes"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterUserAttributes"]._serialized_options = b'\202\326\033!\n\037InFlightOps/AlterUserAttributes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_USER_ATTRIBUTES_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_USER_ATTRIBUTES_COUNT"]._serialized_options = b'\202\326\033\020\n\016UserAttributes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateTableIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateTableIndex"]._serialized_options = b'\202\326\033\036\n\034InFlightOps/CreateTableIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_INDEXES_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_INDEXES_COUNT"]._serialized_options = b'\202\326\033\016\n\014TableIndexes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_PARTITION2_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOCKSTORE_PARTITION2_SHARD_COUNT"]._serialized_options = b'\202\326\033\034\n\032BlockStorePartition2Shards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropTableIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropTableIndex"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/DropTableIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EXTSUB_DOMAIN_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EXTSUB_DOMAIN_COUNT"]._serialized_options = b'\202\326\033\023\n\021ExernalSubDomains'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateExtSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateExtSubDomain"]._serialized_options = b'\202\326\033 \n\036InFlightOps/CreateExtSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_SCHEME_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_SCHEME_SHARD_COUNT"]._serialized_options = b'\202\326\033\030\n\026SubDomainsSchemeShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMergeTablePartition"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMergeTablePartition"]._serialized_options = b'\202\326\033!\n\037InFlightOps/MergeTablePartition'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterExtSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterExtSubDomain"]._serialized_options = b'\202\326\033\037\n\035InFlightOps/AlterExtSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxForceDropExtSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxForceDropExtSubDomain"]._serialized_options = b'\202\326\033#\n!InFlightOps/ForceDropExtSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxFillIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxFillIndex"]._serialized_options = b'\202\326\033\027\n\025InFlightOps/FillIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxUpgradeSubDomain"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxUpgradeSubDomain"]._serialized_options = b'\202\326\033\036\n\034InFlightOps/UpgradeSubDomain'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxUpgradeSubDomainDecision"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxUpgradeSubDomainDecision"]._serialized_options = b'\202\326\033&\n$InFlightOps/UpgradeSubDomainDecision'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_HIVE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SUB_DOMAIN_HIVE_COUNT"]._serialized_options = b'\202\326\033\021\n\017SubDomainsHives'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxInitializeBuildIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxInitializeBuildIndex"]._serialized_options = b'\202\326\033\"\n InFlightOps/InitializeBuildIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SNAPSHOTS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SNAPSHOTS_COUNT"]._serialized_options = b'\202\326\033\013\n\tSnapshots'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_LOCKS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_LOCKS_COUNT"]._serialized_options = b'\202\326\033\007\n\005Locks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateLock"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateLock"]._serialized_options = b'\202\326\033\030\n\026InFlightOps/CreateLock'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterTableIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterTableIndex"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/AlterTableIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxFinalizeBuildIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxFinalizeBuildIndex"]._serialized_options = b'\202\326\033 \n\036InFlightOps/FinalizeBuildIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterSolomonVolume"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterSolomonVolume"]._serialized_options = b'\202\326\033 \n\036InFlightOps/AlterSolomonVolume'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropLock"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropLock"]._serialized_options = b'\202\326\033\026\n\024InFlightOps/DropLock'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropTableIndexAtMainTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropTableIndexAtMainTable"]._serialized_options = b'\202\326\033\'\n%InFlightOps/DropTableIndexAtMainTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SYS_VIEW_PROCESSOR_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SYS_VIEW_PROCESSOR_COUNT"]._serialized_options = b'\202\326\033\023\n\021SysViewProcessors'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_FILESTORE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_FILESTORE_COUNT"]._serialized_options = b'\202\326\033\014\n\nFileStores'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_FILESTORE_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_FILESTORE_SHARD_COUNT"]._serialized_options = b'\202\326\033\021\n\017FileStoreShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateFileStore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateFileStore"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/CreateFileStore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterFileStore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterFileStore"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/AlterFileStore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropFileStore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropFileStore"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/DropFileStore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TTL_ENABLED_TABLE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TTL_ENABLED_TABLE_COUNT"]._serialized_options = b'\202\326\033\022\n\020TTLEnabledTables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxRestore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxRestore"]._serialized_options = b'\202\326\033\025\n\023InFlightOps/Restore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateOlapStore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateOlapStore"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/CreateOlapStore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterOlapStore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterOlapStore"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/AlterOlapStore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropOlapStore"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropOlapStore"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/DropOlapStore'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateColumnTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateColumnTable"]._serialized_options = b'\202\326\033\037\n\035InFlightOps/CreateColumnTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterColumnTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterColumnTable"]._serialized_options = b'\202\326\033\036\n\034InFlightOps/AlterColumnTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropColumnTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropColumnTable"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/DropColumnTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_OLAP_STORE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_OLAP_STORE_COUNT"]._serialized_options = b'\202\326\033\014\n\nOlapStores'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COLUMN_TABLE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COLUMN_TABLE_COUNT"]._serialized_options = b'\202\326\033\016\n\014ColumnTables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DEPRECATED_90"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DEPRECATED_90"]._serialized_options = b'\202\326\033\020\n\016OlapMetaShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COLUMN_SHARDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COLUMN_SHARDS"]._serialized_options = b'\202\326\033\016\n\014ColumnShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_TABLES_DATA_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_TABLES_DATA_BYTES"]._serialized_options = b'\202\326\033\032\n\030DiskSpaceTablesDataBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_TABLES_INDEX_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_TABLES_INDEX_BYTES"]._serialized_options = b'\202\326\033\033\n\031DiskSpaceTablesIndexBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_TABLES_TOTAL_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_TABLES_TOTAL_BYTES"]._serialized_options = b'\202\326\033\033\n\031DiskSpaceTablesTotalBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_QUOTA_EXCEEDED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_QUOTA_EXCEEDED"]._serialized_options = b'\202\326\033\030\n\026DiskSpaceQuotaExceeded'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_HARD_QUOTA_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_HARD_QUOTA_BYTES"]._serialized_options = b'\202\326\033\031\n\027DiskSpaceHardQuotaBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_SOFT_QUOTA_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SPACE_SOFT_QUOTA_BYTES"]._serialized_options = b'\202\326\033\031\n\027DiskSpaceSoftQuotaBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateCdcStream"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateCdcStream"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/CreateCdcStream'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateCdcStreamAtTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateCdcStreamAtTable"]._serialized_options = b'\202\326\033$\n\"InFlightOps/CreateCdcStreamAtTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterCdcStream"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterCdcStream"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/AlterCdcStream'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterCdcStreamAtTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterCdcStreamAtTable"]._serialized_options = b'\202\326\033#\n!InFlightOps/AlterCdcStreamAtTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropCdcStream"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropCdcStream"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/DropCdcStream'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropCdcStreamAtTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropCdcStreamAtTable"]._serialized_options = b'\202\326\033\"\n InFlightOps/DropCdcStreamAtTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_CDC_STREAMS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_CDC_STREAMS_COUNT"]._serialized_options = b'\202\326\033\014\n\nCdcStreams'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMoveTable"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMoveTable"]._serialized_options = b'\202\326\033\027\n\025InFlightOps/MoveTable'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMoveTableIndex"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxMoveTableIndex"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/MoveTableIndex'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_COUNT"]._serialized_options = b'\202\326\033\013\n\tSequences'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCESHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCESHARD_COUNT"]._serialized_options = b'\202\326\033\020\n\016SequenceShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateSequence"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateSequence"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/CreateSequence'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterSequence"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterSequence"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/AlterSequence'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropSequence"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropSequence"]._serialized_options = b'\202\326\033\032\n\030InFlightOps/DropSequence'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_SHARDS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_SHARDS_COUNT"]._serialized_options = b'\202\326\033\023\n\021StreamShardsCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_SHARDS_QUOTA"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_SHARDS_QUOTA"]._serialized_options = b'\202\326\033\023\n\021StreamShardsQuota'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_SIZE"]._serialized_options = b'\202\326\033\037\n\035BackgroundCompactionQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_RESERVED_THROUGHPUT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_RESERVED_THROUGHPUT"]._serialized_options = b'\202\326\033\032\n\030StreamReservedThroughput'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_RESERVED_STORAGE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_RESERVED_STORAGE"]._serialized_options = b'\202\326\033\027\n\025StreamReservedStorage'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_RESERVED_STORAGE_QUOTA"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STREAM_RESERVED_STORAGE_QUOTA"]._serialized_options = b'\202\326\033\034\n\032StreamReservedStorageQuota'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_REPLICATION_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_REPLICATION_COUNT"]._serialized_options = b'\202\326\033\016\n\014Replications'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_REPLICATION_CONTROLLER_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_REPLICATION_CONTROLLER_COUNT"]._serialized_options = b'\202\326\033\030\n\026ReplicationControllers'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateReplication"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateReplication"]._serialized_options = b'\202\326\033\037\n\035InFlightOps/CreateReplication'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterReplication"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterReplication"]._serialized_options = b'\202\326\033\036\n\034InFlightOps/AlterReplication'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropReplication"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropReplication"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/DropReplication'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_SIZE_SH"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_SIZE_SH"]._serialized_options = b'\202\326\033-\n+BackgroundCompactionQueueSizeBySearchHeight'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_SIZE_DELETES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_SIZE_DELETES"]._serialized_options = b'\202\326\033+\n)BackgroundCompactionQueueSizeByRowDeletes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_RUNNING"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_RUNNING"]._serialized_options = b'\202\326\033\"\n BackgroundCompactionQueueRunning'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_WAITING_REPEAT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTION_QUEUE_WAITING_REPEAT"]._serialized_options = b'\202\326\033(\n&BackgroundCompactionQueueWaitingRepeat'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_BORROWED_DATA"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_BORROWED_DATA"]._serialized_options = b'\202\326\033\035\n\033TableShardsWithBorrowedData'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_LOANED_DATA"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_LOANED_DATA"]._serialized_options = b'\202\326\033\033\n\031TableShardsWithLoanedData'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_QUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_QUEUE_SIZE"]._serialized_options = b'\202\326\033\035\n\033BorrowedCompactionQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_QUEUE_RUNNING"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_QUEUE_RUNNING"]._serialized_options = b'\202\326\033 \n\036BorrowedCompactionQueueRunning'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOB_DEPOT_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOB_DEPOT_COUNT"]._serialized_options = b'\202\326\033\014\n\nBlobDepots'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOB_DEPOT_SHARD_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BLOB_DEPOT_SHARD_COUNT"]._serialized_options = b'\202\326\033\021\n\017BlobDepotShards'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateBlobDepot"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateBlobDepot"]._serialized_options = b'\202\326\033\035\n\033InFlightOps/CreateBlobDepot'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterBlobDepot"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterBlobDepot"]._serialized_options = b'\202\326\033\034\n\032InFlightOps/AlterBlobDepot'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropBlobDepot"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxDropBlobDepot"]._serialized_options = b'\202\326\033\033\n\031InFlightOps/DropBlobDepot'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATS_QUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATS_QUEUE_SIZE"]._serialized_options = b'\202\326\033\020\n\016StatsQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxUpdateMainTableOnIndexMove"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxUpdateMainTableOnIndexMove"]._serialized_options = b'\202\326\033(\n&InFlightOps/UpdateMainTableOnIndexMove'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAllocatePQ"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAllocatePQ"]._serialized_options = b'\202\326\033\030\n\026InFlightOps/AllocatePQ'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateCdcStreamAtTableWithSnapshot"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxCreateCdcStreamAtTableWithSnapshot"]._serialized_options = b'\202\326\0330\n.InFlightOps/CreateCdcStreamAtTableWithSnapshot'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterExtSubDomainCreateHive"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_OPS_TxAlterExtSubDomainCreateHive"]._serialized_options = b'\202\326\033)\n\'InFlightOps/AlterExtSubDomainCreateHive'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxInvalid"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxInvalid"]._serialized_options = b'\202\326\033\025\n\023FinishedOps/Invalid'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMkDir"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMkDir"]._serialized_options = b'\202\326\033\023\n\021FinishedOps/MkDir'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateTable"]._serialized_options = b'\202\326\033\031\n\027FinishedOps/CreateTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreatePQGroup"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreatePQGroup"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/CreatePQGroup'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterPQGroup"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterPQGroup"]._serialized_options = b'\202\326\033\032\n\030FinishedOps/AlterPQGroup'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterTable"]._serialized_options = b'\202\326\033\030\n\026FinishedOps/AlterTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropTable"]._serialized_options = b'\202\326\033\027\n\025FinishedOps/DropTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropPQGroup"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropPQGroup"]._serialized_options = b'\202\326\033\031\n\027FinishedOps/DropPQGroup'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxModifyACL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxModifyACL"]._serialized_options = b'\202\326\033\027\n\025FinishedOps/ModifyACL'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxRmDir"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxRmDir"]._serialized_options = b'\202\326\033\023\n\021FinishedOps/RmDir'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCopyTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCopyTable"]._serialized_options = b'\202\326\033\027\n\025FinishedOps/CopyTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxSplitTablePartition"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxSplitTablePartition"]._serialized_options = b'\202\326\033!\n\037FinishedOps/SplitTablePartition'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxBackup"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxBackup"]._serialized_options = b'\202\326\033\024\n\022FinishedOps/Backup'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateSubDomain"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/CreateSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropSubDomain"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/DropSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateRtmrVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateRtmrVolume"]._serialized_options = b'\202\326\033\036\n\034FinishedOps/CreateRtmrVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateBlockStoreVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateBlockStoreVolume"]._serialized_options = b'\202\326\033$\n\"FinishedOps/CreateBlockStoreVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterBlockStoreVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterBlockStoreVolume"]._serialized_options = b'\202\326\033#\n!FinishedOps/AlterBlockStoreVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAssignBlockStoreVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAssignBlockStoreVolume"]._serialized_options = b'\202\326\033$\n\"FinishedOps/AssignBlockStoreVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropBlockStoreVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropBlockStoreVolume"]._serialized_options = b'\202\326\033\"\n FinishedOps/DropBlockStoreVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_UNKNOWN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_UNKNOWN"]._serialized_options = b'\202\326\033\025\n\023FinishedOps/UNKNOWN'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateKesus"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateKesus"]._serialized_options = b'\202\326\033\031\n\027FinishedOps/CreateKesus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropKesus"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropKesus"]._serialized_options = b'\202\326\033\027\n\025FinishedOps/DropKesus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxForceDropSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxForceDropSubDomain"]._serialized_options = b'\202\326\033 \n\036FinishedOps/ForceDropSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateSolomonVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateSolomonVolume"]._serialized_options = b'\202\326\033!\n\037FinishedOps/CreateSolomonVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropSolomonVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropSolomonVolume"]._serialized_options = b'\202\326\033\037\n\035FinishedOps/DropSolomonVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterKesus"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterKesus"]._serialized_options = b'\202\326\033\030\n\026FinishedOps/AlterKesus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterSubDomain"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/AlterSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterUserAttributes"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterUserAttributes"]._serialized_options = b'\202\326\033!\n\037FinishedOps/AlterUserAttributes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateTableIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateTableIndex"]._serialized_options = b'\202\326\033\036\n\034FinishedOps/CreateTableIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropTableIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropTableIndex"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/DropTableIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateExtSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateExtSubDomain"]._serialized_options = b'\202\326\033 \n\036FinishedOps/CreateExtSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMergeTablePartition"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMergeTablePartition"]._serialized_options = b'\202\326\033!\n\037FinishedOps/MergeTablePartition'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterExtSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterExtSubDomain"]._serialized_options = b'\202\326\033\037\n\035FinishedOps/AlterExtSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxForceDropExtSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxForceDropExtSubDomain"]._serialized_options = b'\202\326\033#\n!FinishedOps/ForceDropExtSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxFillIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxFillIndex"]._serialized_options = b'\202\326\033\027\n\025FinishedOps/FillIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxUpgradeSubDomain"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxUpgradeSubDomain"]._serialized_options = b'\202\326\033\036\n\034FinishedOps/UpgradeSubDomain'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxUpgradeSubDomainDecision"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxUpgradeSubDomainDecision"]._serialized_options = b'\202\326\033&\n$FinishedOps/UpgradeSubDomainDecision'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxInitializeBuildIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxInitializeBuildIndex"]._serialized_options = b'\202\326\033\"\n FinishedOps/InitializeBuildIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateLock"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateLock"]._serialized_options = b'\202\326\033\030\n\026FinishedOps/CreateLock'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterTableIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterTableIndex"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/AlterTableIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxFinalizeBuildIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxFinalizeBuildIndex"]._serialized_options = b'\202\326\033 \n\036FinishedOps/FinalizeBuildIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterSolomonVolume"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterSolomonVolume"]._serialized_options = b'\202\326\033 \n\036FinishedOps/AlterSolomonVolume'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropLock"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropLock"]._serialized_options = b'\202\326\033\026\n\024FinishedOps/DropLock'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropTableIndexAtMainTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropTableIndexAtMainTable"]._serialized_options = b'\202\326\033\'\n%FinishedOps/DropTableIndexAtMainTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateFileStore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateFileStore"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/CreateFileStore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterFileStore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterFileStore"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/AlterFileStore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropFileStore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropFileStore"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/DropFileStore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxRestore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxRestore"]._serialized_options = b'\202\326\033\025\n\023FinishedOps/Restore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateOlapStore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateOlapStore"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/CreateOlapStore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterOlapStore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterOlapStore"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/AlterOlapStore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropOlapStore"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropOlapStore"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/DropOlapStore'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateColumnTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateColumnTable"]._serialized_options = b'\202\326\033\037\n\035FinishedOps/CreateColumnTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterColumnTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterColumnTable"]._serialized_options = b'\202\326\033\036\n\034FinishedOps/AlterColumnTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropColumnTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropColumnTable"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/DropColumnTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateCdcStream"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateCdcStream"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/CreateCdcStream'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateCdcStreamAtTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateCdcStreamAtTable"]._serialized_options = b'\202\326\033$\n\"FinishedOps/CreateCdcStreamAtTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterCdcStream"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterCdcStream"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/AlterCdcStream'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterCdcStreamAtTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterCdcStreamAtTable"]._serialized_options = b'\202\326\033#\n!FinishedOps/AlterCdcStreamAtTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropCdcStream"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropCdcStream"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/DropCdcStream'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropCdcStreamAtTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropCdcStreamAtTable"]._serialized_options = b'\202\326\033\"\n FinishedOps/DropCdcStreamAtTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMoveTable"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMoveTable"]._serialized_options = b'\202\326\033\027\n\025FinishedOps/MoveTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMoveTableIndex"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxMoveTableIndex"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/MoveTableIndex'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateSequence"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateSequence"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/CreateSequence'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterSequence"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterSequence"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/AlterSequence'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropSequence"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropSequence"]._serialized_options = b'\202\326\033\032\n\030FinishedOps/DropSequence'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_FAILED"]._serialized_options = b'\202\326\033\034\n\032BackgroundCompactionFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_OK"]._serialized_options = b'\202\326\033\030\n\026BackgroundCompactionOK'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_TIMEOUT"]._serialized_options = b'\202\326\033\035\n\033BackgroundCompactionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateReplication"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateReplication"]._serialized_options = b'\202\326\033\037\n\035FinishedOps/CreateReplication'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterReplication"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterReplication"]._serialized_options = b'\202\326\033\036\n\034FinishedOps/AlterReplication'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropReplication"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropReplication"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/DropReplication'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_BORROWED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_BORROWED"]._serialized_options = b'\202\326\033\036\n\034BackgroundCompactionBorrowed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_NOT_NEEDED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_NOT_NEEDED"]._serialized_options = b'\202\326\033\037\n\035BackgroundCompactionNotNeeded'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_LOANED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_LOANED"]._serialized_options = b'\202\326\033\034\n\032BackgroundCompactionLoaned'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_OK"]._serialized_options = b'\202\326\033\026\n\024BorrowedCompactionOK'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BORROWED_COMPACTION_TIMEOUT"]._serialized_options = b'\202\326\033\033\n\031BorrowedCompactionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateBlobDepot"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateBlobDepot"]._serialized_options = b'\202\326\033\035\n\033FinishedOps/CreateBlobDepot'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterBlobDepot"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterBlobDepot"]._serialized_options = b'\202\326\033\034\n\032FinishedOps/AlterBlobDepot'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropBlobDepot"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxDropBlobDepot"]._serialized_options = b'\202\326\033\033\n\031FinishedOps/DropBlobDepot'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_STATS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_STATS_WRITTEN"]._serialized_options = b'\202\326\033\016\n\014StatsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxUpdateMainTableOnIndexMove"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxUpdateMainTableOnIndexMove"]._serialized_options = b'\202\326\033(\n&FinishedOps/UpdateMainTableOnIndexMove'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAllocatePQ"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAllocatePQ"]._serialized_options = b'\202\326\033\030\n\026FinishedOps/AllocatePQ'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateCdcStreamAtTableWithSnapshot"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxCreateCdcStreamAtTableWithSnapshot"]._serialized_options = b'\202\326\0330\n.FinishedOps/CreateCdcStreamAtTableWithSnapshot'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterExtSubDomainCreateHive"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FINISHED_OPS_TxAlterExtSubDomainCreateHive"]._serialized_options = b'\202\326\033)\n\'FinishedOps/AlterExtSubDomainCreateHive'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_OK_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_BACKGROUND_COMPACTION_OK_LATENCY"]._serialized_options = b'\202\326\033\037\n\035BackgroundCompactionOkLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_NUM_SHARDS_BY_TTL_LAG"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_NUM_SHARDS_BY_TTL_LAG"]._serialized_options = b'\202\326\033z\n\021NumShardsByTtlLag\022\005\010\000\022\0010\022\010\010\204\007\022\003900\022\t\010\210\016\022\0041800\022\t\010\220\034\022\0043600\022\t\010\2408\022\0047200\022\n\010\300p\022\00514400\022\013\010\200\341\001\022\00528800\022\013\010\200\302\003\022\00557600\022\013\010\200\243\005\022\00586400\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_SEARCH_HEIGHT"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_SEARCH_HEIGHT"]._serialized_options = b'\202\326\033\230\001\n\026ShardsWithSearchHeight\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\003\022\0013\022\005\010\004\022\0014\022\005\010\005\022\0015\022\005\010\006\022\0016\022\005\010\007\022\0017\022\005\010\010\022\0018\022\005\010\t\022\0019\022\006\010\n\022\00210\022\006\010\013\022\00211\022\006\010\014\022\00212\022\006\010\r\022\00213\022\006\010\016\022\00214\022\006\010\017\022\00215\022\006\010\024\022\00220\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_FULL_COMPACTION"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_FULL_COMPACTION"]._serialized_options = b'\202\326\033_\n\034ShardsFullCompactionAgeHours\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\006\022\0016\022\006\010\014\022\00212\022\006\010\030\022\00224\022\006\0100\022\00248\022\006\010H\022\00272\022\010\010\250\001\022\003168\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_ROW_DELETES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SHARDS_WITH_ROW_DELETES"]._serialized_options = b'\202\326\033\223\001\n\024ShardsWithRowDeletes\022\005\010\000\022\0010\022\007\010d\022\003100\022\t\010\350\007\022\0041000\022\n\010\220N\022\00510000\022\014\010\240\215\006\022\006100000\022\r\010\300\204=\022\0071000000\022\017\010\200\255\342\004\022\01010000000\022\020\010\200\302\327/\022\t100000000\022\022\010\200\224\353\334\003\022\n1000000000\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_STATS_BATCH_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_STATS_BATCH_LATENCY"]._serialized_options = b'\202\326\033p\n\021StatsBatchLatency\022\t\010\350\007\022\0041 ms\022\n\010\220N\022\00510 ms\022\013\010\320\206\003\022\00550 ms\022\014\010\240\215\006\022\006100 ms\022\014\010\300\232\014\022\006200 ms\022\014\010\240\302\036\022\006500 ms\022\r\010\300\204=\022\0071000 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_INIT_ROOT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_ROOT"]._serialized_options = b'\212\326\033\014\n\nTxInitRoot'
  _ETXTYPES.values_by_name["TXTYPE_PLAN_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PLAN_STEP"]._serialized_options = b'\212\326\033\014\n\nTxPlanStep'
  _ETXTYPES.values_by_name["TXTYPE_DESCRIBE_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DESCRIBE_SCHEME"]._serialized_options = b'\212\326\033\022\n\020TxDescribeScheme'
  _ETXTYPES.values_by_name["TXTYPE_DATASHARD_PROPOSE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DATASHARD_PROPOSE_RESULT"]._serialized_options = b'\212\326\033\032\n\030TxDataShardProposeResult'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_TABLET_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_TABLET_REPLY"]._serialized_options = b'\212\326\033\025\n\023TxCreateTabletReply'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_OP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_OP"]._serialized_options = b'\212\326\033\016\n\014TxProgressOp'
  _ETXTYPES.values_by_name["TXTYPE_PERSQUEUE_CONFIG_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PERSQUEUE_CONFIG_RESULT"]._serialized_options = b'\212\326\033\031\n\027TxPersQueueConfigResult'
  _ETXTYPES.values_by_name["TXTYPE_DROP_TABLET_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_TABLET_RESULT"]._serialized_options = b'\212\326\033\024\n\022TxDropTabletResult'
  _ETXTYPES.values_by_name["TXTYPE_FREE_TABLET_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FREE_TABLET_RESULT"]._serialized_options = b'\212\326\033\024\n\022TxFreeTabletResult'
  _ETXTYPES.values_by_name["TXTYPE_DATASHARD_STATE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DATASHARD_STATE_RESULT"]._serialized_options = b'\212\326\033\030\n\026TxDataShardStateResult'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SPLIT_DST_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SPLIT_DST_ACK"]._serialized_options = b'\212\326\033\023\n\021TxInitSplitDstAck'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_ACK"]._serialized_options = b'\212\326\033\014\n\nTxSplitAck'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_PARTITIONING_CHANGED_DST_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_PARTITIONING_CHANGED_DST_ACK"]._serialized_options = b'\212\326\033\037\n\035TxSplitPartitioningChangedAck'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_BACKUP_IMPL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_BACKUP_IMPL"]._serialized_options = b'\212\326\033\024\n\022TxCancelBackupImpl'
  _ETXTYPES.values_by_name["TXTYPE_MONITORING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MONITORING"]._serialized_options = b'\212\326\033\016\n\014TxMonitoring'
  _ETXTYPES.values_by_name["TXTYPE_SUBDOMAIN_CONFIGURE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SUBDOMAIN_CONFIGURE_RESULT"]._serialized_options = b'\212\326\033\035\n\033TTxSubDomainConfigureStatus'
  _ETXTYPES.values_by_name["TXTYPE_BLOCKSTORE_CONFIG_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_BLOCKSTORE_CONFIG_RESULT"]._serialized_options = b'\212\326\033\033\n\031TTxBlockStoreConfigResult'
  _ETXTYPES.values_by_name["TXTYPE_KESUS_CONFIG_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_KESUS_CONFIG_RESULT"]._serialized_options = b'\212\326\033\026\n\024TTxKesusConfigResult'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._serialized_options = b'\212\326\033\025\n\023TTxOperationPropose'
  _ETXTYPES.values_by_name["TXTYPE_DATASHARD_SCHEMA_CHANGED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DATASHARD_SCHEMA_CHANGED"]._serialized_options = b'\212\326\033\032\n\030TxDataShardSchemaChanged'
  _ETXTYPES.values_by_name["TXTYPE_DEFERRED_UPDATE_ON_SCHEME_BOARD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DEFERRED_UPDATE_ON_SCHEME_BOARD"]._serialized_options = b'\212\326\033\037\n\035TxDeferredUpdateOnSchemeBoard'
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_TABLES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_TABLES"]._serialized_options = b'\212\326\033\017\n\rTxCleanTables'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_EXPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_EXPORT"]._serialized_options = b'\212\326\033\020\n\016TxCreateExport'
  _ETXTYPES.values_by_name["TXTYPE_GET_EXPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_EXPORT"]._serialized_options = b'\212\326\033\r\n\013TxGetExport'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_EXPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_EXPORT"]._serialized_options = b'\212\326\033\020\n\016TxCancelExport'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_EXPORT_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_EXPORT_ACK"]._serialized_options = b'\212\326\033\023\n\021TxCancelExportAck'
  _ETXTYPES.values_by_name["TXTYPE_FORGET_EXPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FORGET_EXPORT"]._serialized_options = b'\212\326\033\020\n\016TxForgetExport'
  _ETXTYPES.values_by_name["TXTYPE_LIST_EXPORTS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LIST_EXPORTS"]._serialized_options = b'\212\326\033\017\n\rTxListExports'
  _ETXTYPES.values_by_name["TXTYPE_EXPORT_PROGRESS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_EXPORT_PROGRESS"]._serialized_options = b'\212\326\033\022\n\020TxExportProgress'
  _ETXTYPES.values_by_name["TXTYPE_SYNC_TENANT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SYNC_TENANT"]._serialized_options = b'\212\326\033\016\n\014TxSyncTenant'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TENANT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TENANT"]._serialized_options = b'\212\326\033\020\n\016TxUpdateTenant'
  _ETXTYPES.values_by_name["TXTYPE_FREE_OWNER_TABLETS_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FREE_OWNER_TABLETS_RESULT"]._serialized_options = b'\212\326\033\032\n\030TxFreeOwnerTabletsResult'
  _ETXTYPES.values_by_name["TXTYPE_SUBDOMAIN_MIGRATE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SUBDOMAIN_MIGRATE_RESULT"]._serialized_options = b'\212\326\033\033\n\031TTxSubDomainMigrateResult'
  _ETXTYPES.values_by_name["TXTYPE_SUBDOMAIN_MIGRATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SUBDOMAIN_MIGRATE"]._serialized_options = b'\212\326\033\025\n\023TTxSubDomainMigrate'
  _ETXTYPES.values_by_name["TXTYPE_UPGRADE_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPGRADE_SCHEME"]._serialized_options = b'\212\326\033\022\n\020TTxUpgradeScheme'
  _ETXTYPES.values_by_name["TXTYPE_INIT_POPULATOR"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_POPULATOR"]._serialized_options = b'\212\326\033\022\n\020TTxInitPopulator'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_INDEX_BUILD"]._serialized_options = b'\212\326\033\024\n\022TxCreateIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_GET_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_INDEX_BUILD"]._serialized_options = b'\212\326\033\021\n\017TxGetIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_INDEX_BUILD"]._serialized_options = b'\212\326\033\024\n\022TxCancelIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_FORGET_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FORGET_INDEX_BUILD"]._serialized_options = b'\212\326\033\024\n\022TxForgetIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_LIST_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LIST_INDEX_BUILD"]._serialized_options = b'\212\326\033\022\n\020TxListIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_INDEX_BUILD"]._serialized_options = b'\212\326\033\026\n\024TxProgressIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_SCHEDULE_CONDITIONAL_ERASE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SCHEDULE_CONDITIONAL_ERASE"]._serialized_options = b'\212\326\033\034\n\032TxScheduleConditionalErase'
  _ETXTYPES.values_by_name["TXTYPE_RUN_CONDITIONAL_ERASE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RUN_CONDITIONAL_ERASE"]._serialized_options = b'\212\326\033\027\n\025TxRunConditionalErase'
  _ETXTYPES.values_by_name["TXTYPE_STORE_PARTITION_STATS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_PARTITION_STATS"]._serialized_options = b'\212\326\033\027\n\025TxStorePartitionStats'
  _ETXTYPES.values_by_name["TXTYPE_FILESTORE_CONFIG_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FILESTORE_CONFIG_RESULT"]._serialized_options = b'\212\326\033\031\n\027TxFileStoreConfigResult'
  _ETXTYPES.values_by_name["TXTYPE_MAKEBILL_INDEX_BUILD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MAKEBILL_INDEX_BUILD"]._serialized_options = b'\212\326\033\025\n\023TxBillingIndexBuild'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_IMPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_IMPORT"]._serialized_options = b'\212\326\033\020\n\016TxCreateImport'
  _ETXTYPES.values_by_name["TXTYPE_GET_IMPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_IMPORT"]._serialized_options = b'\212\326\033\r\n\013TxGetImport'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_IMPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_IMPORT"]._serialized_options = b'\212\326\033\020\n\016TxCancelImport'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_IMPORT_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_IMPORT_ACK"]._serialized_options = b'\212\326\033\023\n\021TxCancelImportAck'
  _ETXTYPES.values_by_name["TXTYPE_FORGET_IMPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FORGET_IMPORT"]._serialized_options = b'\212\326\033\020\n\016TxForgetImport'
  _ETXTYPES.values_by_name["TXTYPE_LIST_IMPORTS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LIST_IMPORTS"]._serialized_options = b'\212\326\033\017\n\rTxListImports'
  _ETXTYPES.values_by_name["TXTYPE_IMPORT_PROGRESS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_IMPORT_PROGRESS"]._serialized_options = b'\212\326\033\022\n\020TxImportProgress'
  _ETXTYPES.values_by_name["TXTYPE_SERVERLESS_STORAGE_BILLING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SERVERLESS_STORAGE_BILLING"]._serialized_options = b'\212\326\033\034\n\032TxServerlessStorageBilling'
  _ETXTYPES.values_by_name["TXTYPE_OLAPSHARD_PROPOSE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_OLAPSHARD_PROPOSE_RESULT"]._serialized_options = b'\212\326\033\032\n\030TxOlapShardProposeResult'
  _ETXTYPES.values_by_name["TXTYPE_COLUMNSHARD_PROPOSE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COLUMNSHARD_PROPOSE_RESULT"]._serialized_options = b'\212\326\033\034\n\032TxColumnShardProposeResult'
  _ETXTYPES.values_by_name["TXTYPE_OLAPSHARD_NOTIFY_TX_COMPLETION_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_OLAPSHARD_NOTIFY_TX_COMPLETION_RESULT"]._serialized_options = b'\212\326\033%\n#TxOlapShardNotifyTxCompletionResult'
  _ETXTYPES.values_by_name["TXTYPE_COLUMNSHARD_NOTIFY_TX_COMPLETION_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COLUMNSHARD_NOTIFY_TX_COMPLETION_RESULT"]._serialized_options = b'\212\326\033\'\n%TxColumnShardNotifyTxCompletionResult'
  _ETXTYPES.values_by_name["TXTYPE_FIND_TABLET_SUBDOMAIN_PATH_ID"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FIND_TABLET_SUBDOMAIN_PATH_ID"]._serialized_options = b'\212\326\033\035\n\033TxFindTabletSubDomainPathId'
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_BLOCKSTORE_VOLUMES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_BLOCKSTORE_VOLUMES"]._serialized_options = b'\212\326\033\032\n\030TxCleanBlockStoreVolumes'
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_DROPPED_PATHS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_DROPPED_PATHS"]._serialized_options = b'\212\326\033\025\n\023TxCleanDroppedPaths'
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_DROPPED_SUBDOMAINS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CLEAN_DROPPED_SUBDOMAINS"]._serialized_options = b'\212\326\033\032\n\030TxCleanDroppedSubDomains'
  _ETXTYPES.values_by_name["TXTYPE_LOGIN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOGIN"]._serialized_options = b'\212\326\033\t\n\007TxLogin'
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_CREATE_SEQUENCE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_CREATE_SEQUENCE_RESULT"]._serialized_options = b'\212\326\033%\n#TxSequenceShardCreateSequenceResult'
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_DROP_SEQUENCE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_DROP_SEQUENCE_RESULT"]._serialized_options = b'\212\326\033#\n!TxSequenceShardDropSequenceResult'
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_UPDATE_SEQUENCE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_UPDATE_SEQUENCE_RESULT"]._serialized_options = b'\212\326\033%\n#TxSequenceShardUpdateSequenceResult'
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_FREEZE_SEQUENCE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_FREEZE_SEQUENCE_RESULT"]._serialized_options = b'\212\326\033%\n#TxSequenceShardFreezeSequenceResult'
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_RESTORE_SEQUENCE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_RESTORE_SEQUENCE_RESULT"]._serialized_options = b'\212\326\033&\n$TxSequenceShardRestoreSequenceResult'
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_REDIRECT_SEQUENCE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEQUENCESHARD_REDIRECT_SEQUENCE_RESULT"]._serialized_options = b'\212\326\033\'\n%TxSequenceShardRedirectSequenceResult'
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_OPERATION_COMPLETE_PUBLICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_OPERATION_COMPLETE_PUBLICATION"]._serialized_options = b'\212\326\033&\n$TxNotifyOperationCompletePublication'
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_OPERATION_COMPLETE_BARRIER"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_OPERATION_COMPLETE_BARRIER"]._serialized_options = b'\212\326\033\"\n TxNotifyOperationCompleteBarrier'
  _ETXTYPES.values_by_name["TXTYPE_PARTITION_HISTOGRAM"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PARTITION_HISTOGRAM"]._serialized_options = b'\212\326\033\026\n\024TxPartitionHistogram'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_REPLICATION_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_REPLICATION_RESULT"]._serialized_options = b'\212\326\033\033\n\031TxCreateReplicationResult'
  _ETXTYPES.values_by_name["TXTYPE_ALTER_REPLICATION_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ALTER_REPLICATION_RESULT"]._serialized_options = b'\212\326\033\032\n\030TxAlterReplicationResult'
  _ETXTYPES.values_by_name["TXTYPE_DROP_REPLICATION_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_REPLICATION_RESULT"]._serialized_options = b'\212\326\033\031\n\027TxDropReplicationResult'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_BLOB_DEPOT_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_BLOB_DEPOT_RESULT"]._serialized_options = b'\212\326\033\031\n\027TxCreateBlobDepotResult'
  _ETXTYPES.values_by_name["TXTYPE_ALTER_BLOB_DEPOT_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ALTER_BLOB_DEPOT_RESULT"]._serialized_options = b'\212\326\033\030\n\026TxAlterBlobDepotResult'
  _ETXTYPES.values_by_name["TXTYPE_DROP_BLOB_DEPOT_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_BLOB_DEPOT_RESULT"]._serialized_options = b'\212\326\033\027\n\025TxDropBlobDepotResult'
  _ETXTYPES.values_by_name["TXTYPE_BLOB_DEPOT_CONFIG_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_BLOB_DEPOT_CONFIG_RESULT"]._serialized_options = b'\212\326\033\031\n\027TxBlobDepotConfigResult'
  _ETXTYPES.values_by_name["TXTYPE_ADD_BACKGROUND_TASK_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ADD_BACKGROUND_TASK_RESULT"]._serialized_options = b'\212\326\033\033\n\031TxAddBackgroundTaskResult'
  _ESIMPLECOUNTERS._serialized_start=101
  _ESIMPLECOUNTERS._serialized_end=10213
  _ECUMULATIVECOUNTERS._serialized_start=10216
  _ECUMULATIVECOUNTERS._serialized_end=16916
  _EPERCENTILECOUNTERS._serialized_start=16919
  _EPERCENTILECOUNTERS._serialized_end=18225
  _ETXTYPES._serialized_start=18228
  _ETXTYPES._serialized_end=23328
# @@protoc_insertion_point(module_scope)
